@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2014 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2016 Live Networks, Inc.  All rights reserved.
 // Framed Sources
 // Implementation
 
@@ -94,9 +94,13 @@ void FramedSource::afterGetting(FramedSource* source) {
 
 void FramedSource::handleClosure(void* clientData) {
   FramedSource* source = (FramedSource*)clientData;
-  source->fIsCurrentlyAwaitingData = False; // because we got a close instead
-  if (source->fOnCloseFunc != NULL) {
-    (*(source->fOnCloseFunc))(source->fOnCloseClientData);
+  source->handleClosure();
+}
+
+void FramedSource::handleClosure() {
+  fIsCurrentlyAwaitingData = False; // because we got a close instead
+  if (fOnCloseFunc != NULL) {
+    (*fOnCloseFunc)(fOnCloseClientData);
   }
 }
 
