@@ -1742,6 +1742,10 @@ void RTSPClient::handleResponseBytes(int newBytesRead) {
 	    setBaseURL(newBaseURL);
 	    delete[] newBaseURL;
 	  }
+	} else if (checkForHeader(lineStart, "Connection:", 11, headerParamsStr)) {
+	  if (_strncasecmp(headerParamsStr, "Close", 5) == 0) {
+	    resetTCPSockets();
+	  }
 	}
       }
       if (!reachedEndOfHeaders) break; // an error occurred
@@ -1960,6 +1964,7 @@ RTSPClient::RequestRecord* RTSPClient::RequestQueue::findByCSeq(unsigned cseq) {
 }
 
 
+#ifndef OMIT_REGISTER_HANDLING
 ////////// HandlerServerForREGISTERCommand implementation /////////
 
 HandlerServerForREGISTERCommand* HandlerServerForREGISTERCommand
@@ -2004,3 +2009,4 @@ void HandlerServerForREGISTERCommand::implementCmd_REGISTER(char const* url, cha
 
   if (fCreationFunc != NULL) (*fCreationFunc)(newRTSPClient, deliverViaTCP);
 }
+#endif
