@@ -11,7 +11,7 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 **********/
 // Copyright (c) 1996-2016, Live Networks, Inc.  All rights reserved
 // A test program that reads a H.265 Elementary Stream video file
